/*
  Macro           TimesMinus2
  Author          Carlo Hogeveen
  Website         eCarlo.nl/tse
  Compatibility   Tested with Windows GUI TSE v4.50 rc 17.
  Version         v1   31 Jan 2024

  This tool helps make DirList output comparable between Linux and Windows
  by diminishing all " h:mm:ss" and "hh:mm:ss" times it finds by 2 seconds.

  The tool works on the whole file.
  It does not diminish the date if the old time is 0:00:00 or 00:00:00.


  REASON

  If you run DirList from Windows TSE and Linux TSE on the same directory
  of a Linux system in WSL, then the times usually differ by 2 seconds, because
  currently Windows TSE rounds up and Linux TSE rounds down to even seconds.
  This makes it hard to compare results.

*/

proc Main()
  integer hours    = 0
  integer minutes  = 0
  integer seconds  = 0
  string  time [8] = ''

  PushPosition()
  BegFile()

  while lFind('[ 0-9][0-9]:[0-9][0-9]:[0-9][0-9]', 'x+')
    time    = GetFoundText()
    seconds = Val(time[7:2])
    if (seconds in 0, 1)
      seconds = seconds + 60 - 2
      minutes = Val(time[4:2])
      if minutes == 0
        minutes = 59
        if hours == 0
          hours = 23
        else
          hours = hours - 1
        endif
        if time[1:1] == ' '
          time = Format(hours:2:' ', time[3:6])
        else
          time = Format(hours:2:'0', time[3:6])
        endif
      else
        minutes = minutes - 1
      endif
      time = Format(time[1:3], minutes:2:'0', time[6:3])
    else
      seconds = seconds - 2
    endif
    time = Format(time[1:6], seconds:2:'0')
    InsertText(time, _OVERWRITE_)
  endwhile

  PopPosition()
end Main

